@@ -5,6 +5,7 @@
 */
 
 #include "checkfoldersizeaccountplugin.h"
+#include "checkfoldersizeaccountpluginconfiguredialog.h"
 #include "checkfoldersizeaccountplugininterface.h"
 #include <KPluginFactory>
 
@@ -15,12 +16,23 @@ CheckFolderSizeAccountPlugin::CheckFolderSizeAccountPlugin(QObject *parent, cons
 {
 }
 
+CheckFolderSizeAccountPlugin::~CheckFolderSizeAccountPlugin() = default;
+
 PimCommon::GenericPluginInterface *CheckFolderSizeAccountPlugin::createInterface(QObject *parent)
 {
     return new CheckFolderSizeAccountPluginInterface(parent);
 }
 
-CheckFolderSizeAccountPlugin::~CheckFolderSizeAccountPlugin() = default;
+bool CheckFolderSizeAccountPlugin::hasConfigureDialog() const
+{
+    return true;
+}
+
+void CheckFolderSizeAccountPlugin::showConfigureDialog(QWidget *parent)
+{
+    CheckFolderSizeAccountPluginConfigureDialog dlg(parent);
+    dlg.exec();
+}
 
 #include "checkfoldersizeaccountplugin.moc"
 #include "moc_checkfoldersizeaccountplugin.cpp"
